@@ -27,6 +27,11 @@ from ssh_proxy_server.forwarders.sftp import (
     SFTPHandlerPlugin
 )
 
+from ssh_proxy_server.interfaces.sftp import (
+    BaseSFTPServerInterface,
+    SFTPProxyServerInterface
+)
+
 
 def main():
     parser = ModuleParser(description='SSH Proxy Server', baseclass=BaseForwarder, modules_from_file=True)
@@ -71,6 +76,13 @@ def main():
         help='ProxyManager to manage the Proxy',
         baseclass=SCPBaseForwarder
     )
+    parser.add_module(
+        '--sftp-interface',
+        dest='sftp_interface',
+        default=SFTPProxyServerInterface,
+        help='SFTP Handler to handle sftp file transfers',
+        baseclass=BaseSFTPServerInterface
+    )
     parser.add_module(
         '--sftp-handler',
         dest='sftp_handler',
@@ -113,6 +125,7 @@ def main():
         key_file=args.host_key,
         ssh_interface=args.ssh_interface,
         scp_interface=args.scp_interface,
+        sftp_interface=args.sftp_interface,
         sftp_handler=args.sftp_handler,
         authentication_interface=args.auth_interface,
         authenticator=args.authenticator,
